@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021, OARC, Inc.
+ * Copyright (c) 2018-2022, OARC, Inc.
  * All rights reserved.
  *
  * This file is part of dnsjit.
@@ -20,6 +20,4 @@
 
 #include "config.h"
 
-#include <stdint.h>
-
-#include "core/compat.hh"
+#include "core/compat.h"
